OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "ฟีดกิจกรรมส่วนตัวสำหรับ %s",
    "Your feed URL is invalid" : "ฟีด URL ของคุณไม่ถูกต้อง",
    "Activity feed" : "ฟีดกิจกรรม",
    "Your settings have been updated." : "อัปเดตการตั้งค่าของคุณแล้ว",
    "Settings have been updated." : "อัปเดตการตั้งค่าแล้ว",
    "Recent activity" : "กิจกรรมล่าสุด",
    "No activities" : "ไม่มีกิจกรรม",
    "More activities" : "กิจกรรมเพิ่มเติม",
    "Daily activity summary for %s" : "สรุปกิจกรรมประจำวันสำหรับ %s",
    "_and %n more _::_and %n more _" : ["และอีก %n"],
    "All activities" : "กิจกรรมทั้งหมด",
    "By others" : "โดยผู้อื่น",
    "By you" : "โดยคุณ",
    "Activity at %s" : "กิจกรรมที่ %s",
    "Hello %s" : "สวัสดี %s",
    "Hello %s," : "สวัสดี %s",
    "There was some activity at %s" : "มีกิจกรรมบางอย่างที่ %s",
    "Mail" : "จดหมาย",
    "Push" : "พุช",
    "Activity" : "กิจกรรม",
    "Notifications" : "การแจ้งเตือน",
    "Send email" : "ส่งอีเมล",
    "Send push notification" : "ส่งแจ้งเตือนแบบเด้ง",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวานนี้",
    "You need to set up your email address before you can receive notification emails." : "คุณจะได้รับอีเมลแจ้งเตือนหลังจากที่คุณตั้งค่าที่อยู่อีเมลของคุณ",
    "Send activity emails" : "ส่งอีเมลกิจกรรม",
    "As soon as possible" : "เร็วที่สุดที่เป็นไปได้",
    "Hourly" : "รายชั่วโมง",
    "Daily" : "รายวัน",
    "Weekly" : "รายสัปดาห์",
    "You commented" : "คุณได้แสดงความคิดเห็น",
    "Open {filename}" : "เปิด {filename}",
    "in {path}" : "ใน {path}",
    "Home" : "หน้าหลัก",
    "This stream will show events like additions, changes & shares" : "สตรีมนี้จะแสดงเหตุการณ์ต่าง ๆ เช่น การเพิ่ม การเปลี่ยนแปลง และการแชร์",
    "No activity yet" : "ยังไม่มีกิจกรรม",
    "Enable RSS feed" : "เปิดใช้งานฟีด RSS",
    "RSS feed" : "ฟีด RSS",
    "Copy RSS feed link" : "คัดลอก RSS ฟีตลิงค์",
    "Personal notification settings" : "ตั้งค่าการแจ้งเตือนส่วนบุคคล",
    "Unable to load the activity list" : "ไม่สามารถโหลดรายการกิจกรรม",
    "Notification" : "การแจ้งเตือน",
    "Enable notification emails" : "เปิดอีเมลแจ้งเตือน",
    "Choose for which activities you want to get an email or push notification." : "เลือกกิจกรรมที่คุณต้องการรับอีเมลหรือการแจ้งเตือนพุช",
    "Choose for which activities you want to get a push notification." : "เลือกกิจกรรมที่คุณต้องการรับการแจ้งเตือนพุช",
    "Daily activity summary" : "สรุปการใช้งานรายวัน",
    "Send daily activity summary in the morning" : "ส่งสรุปกิจกรรมประจำวันในตอนเช้า",
    "Default settings" : "ค่าเริ่มต้น",
    "No more events to load" : "ไม่มีกิจกรรมเพิ่มเติมที่จะโหลด",
    "Copied!" : "คัดลอกแล้ว!",
    "Not supported!" : "ไม่สนับสนุน!",
    "Press ⌘-C to copy." : "กด ⌘-C เพื่อคัดลอก",
    "Press Ctrl-C to copy." : "กด Ctrl-C เพื่อคัดลอก",
    "{name} (invisible)" : "{name} (ไม่แสดงสถานะ)",
    "{name} (restricted)" : "{name} (จำกัด)",
    "There are no events for this filter" : "ไม่มีกิจกรรมสำหรับตัวกรองนี้",
    "Activities" : "กิจกรรม"
},
"nplurals=1; plural=0;");
