<?php 
$OC_Version = array(26,0,10,1);
$OC_VersionString = '26.0.10';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '25.0' => true,
    '26.0' => true,
  ),
  'owncloud' => 
  array (
    '10.13' => true,
  ),
);
$OC_Build = '2023-12-14T11:00:37+00:00 d0703ed9512623651392f61580090f9f62d2f0c6';
$vendor = 'nextcloud';
